==> 2.1.0.zip: whatismyip/server/server.go <==
package server

import (
	"log"
	"net/http"
	"os"
	"os/signal"
	"syscall"

	"github.com/dcarrillo/whatismyip/internal/setting"
	"github.com/dcarrillo/whatismyip/models"
	"golang.org/x/net/context"
)

type Server interface {
	Start()
	Stop()
}

type Factory struct {
	tcpServer  *TCPServer
	tlsServer  *TLSServer
	quicServer *QuicServer
}

func Setup(ctx context.Context, handler http.Handler) *Factory {
	var tcpServer *TCPServer
	var tlsServer *TLSServer
	var quicServer *QuicServer

	if setting.App.BindAddress != "" {
		tcpServer = NewTCPServer(ctx, &handler)
	}

	if setting.App.TLSAddress != "" {
		tlsServer = NewTLSServer(ctx, &handler)
		if setting.App.EnableHTTP3 {
			quicServer = NewQuicServer(ctx, tlsServer)
		}
	}

	return &Factory{
		tcpServer:  tcpServer,
		tlsServer:  tlsServer,
		quicServer: quicServer,
	}
}

func (w *Factory) Run() {
	w.start()
	log.Printf("Starting server handler...")
	w.Watcher()
}

func (w *Factory) Watcher() {
	signalChan := make(chan os.Signal, 3)
	signal.Notify(signalChan, syscall.SIGHUP, syscall.SIGINT, syscall.SIGTERM)
	var s os.Signal

	for {
		s = <-signalChan

		if s == syscall.SIGHUP {
			w.stop()
			models.CloseDBs()
			models.Setup(setting.App.GeodbPath.City, setting.App.GeodbPath.ASN)
			w.start()
		} else {
			log.Printf("Shutting down...")
			w.stop()
			models.CloseDBs()
			break
		}
	}
}

func (w *Factory) start() {
	if w.tcpServer != nil {
		w.tcpServer.Start()
	}

	if w.tlsServer != nil {
		w.tlsServer.Start()
		if w.quicServer != nil {
			w.quicServer.Start()
		}
	}
}

func (w *Factory) stop() {
	if w.tcpServer != nil {
		w.tcpServer.Stop()
	}

	if w.tlsServer != nil {
		if w.quicServer != nil {
			w.quicServer.Stop()
		}
		w.tlsServer.Stop()
	}
}

==> 2.1.1.zip: whatismyip/server/server.go <==
package server

import (
	"log"
	"net/http"
	"os"
	"os/signal"
	"syscall"

	"github.com/dcarrillo/whatismyip/internal/setting"
	"github.com/dcarrillo/whatismyip/models"
	"golang.org/x/net/context"
)

type Server interface {
	Start()
	Stop()
}

type Factory struct {
	tcpServer  *TCPServer
	tlsServer  *TLSServer
	quicServer *QuicServer
}

func Setup(ctx context.Context, handler http.Handler) *Factory {
	var tcpServer *TCPServer
	var tlsServer *TLSServer
	var quicServer *QuicServer

	if setting.App.BindAddress != "" {
		tcpServer = NewTCPServer(ctx, &handler)
	}

	if setting.App.TLSAddress != "" {
		tlsServer = NewTLSServer(ctx, &handler)
		if setting.App.EnableHTTP3 {
			quicServer = NewQuicServer(ctx, tlsServer)
		}
	}

	return &Factory{
		tcpServer:  tcpServer,
		tlsServer:  tlsServer,
		quicServer: quicServer,
	}
}

func (f *Factory) Run() {
	f.start()

	signalChan := make(chan os.Signal, 3)
	signal.Notify(signalChan, syscall.SIGHUP, syscall.SIGINT, syscall.SIGTERM)
	var s os.Signal
	for {
		s = <-signalChan

		if s == syscall.SIGHUP {
			f.stop()
			models.CloseDBs()
			models.Setup(setting.App.GeodbPath.City, setting.App.GeodbPath.ASN)
			f.start()
		} else {
			log.Printf("Shutting down...")
			f.stop()
			models.CloseDBs()
			break
		}
	}
}

func (f *Factory) start() {
	if f.tcpServer != nil {
		f.tcpServer.Start()
	}

	if f.tlsServer != nil {
		f.tlsServer.Start()
		if f.quicServer != nil {
			f.quicServer.Start()
		}
	}
}

func (f *Factory) stop() {
	if f.tcpServer != nil {
		f.tcpServer.Stop()
	}

	if f.tlsServer != nil {
		if f.quicServer != nil {
			f.quicServer.Stop()
		}
		f.tlsServer.Stop()
	}
}
